// set environment to production, staging, or debug (for local dev)
window.APP_ENVIRONMENT = "production";

// set all the flags for the specified environment
// if needed, edit flags manually within the environment:
//   - CONTACTS_TESTING - if true, will set all contact emails to unicorns@infuse.us during the initial import
//   - STAGINGE_SERVER - If true, will point the app to the staging server rather than the production server
//   - ANALYTICS_IS_TEST - if true, all Mixpanel/Amplitude event calls and LogEntries logs will go to the test accounts
if (window.APP_ENVIRONMENT == "production") {
    window.CONTACTS_TESTING = false;
    window.TEST_NOTIFICATIONS = false;
    window.STAGING_SERVER = false;
    window.ANALYTICS_IS_TEST = false;
} else if (window.APP_ENVIRONMENT == "staging") {
    window.CONTACTS_TESTING = false;
    window.TEST_NOTIFICATIONS = true;
    window.STAGING_SERVER = true;
    window.ANALYTICS_IS_TEST = true;
} else {
    window.CONTACTS_TESTING = true;
    window.TEST_NOTIFICATIONS = true;
    window.STAGING_SERVER = true;
    window.ANALYTICS_IS_TEST = true;
}

// production keys
var analyticsLogEntriesKey = "7d7429e1-e16e-4306-8327-35168243c732";
var analyticsMixPanelKey = "bfd1e2dc9454bd0b4c20858011cde3a1";
var analyticsAmplitudeKey = "6a3a2a86245a273a593577dc7f6262ec";
if (window.ANALYTICS_IS_TEST) {
    // test keys
    analyticsLogEntriesKey = "a3193eca-b985-4dd8-a08b-a969759f422d";
    analyticsMixPanelKey = "10bda9f06343bf3d3cc2657094372247";
    analyticsAmplitudeKey = "cbea980719cdc0e21d084a5d3c5369ea";
}

LE.init(analyticsLogEntriesKey);

var getStacktrace = function() {
	function st2(f) {
	    if (!f || f.length === 0) {
	        return [];
	    } else {
	        return st2(f.caller).concat([f.toString().split('(')[0].substring(9) + '(' + f.arguments.join() + ')']);
	    }
	}
	return st2(arguments.callee.caller);
};
// extractLineNumberFromStack is not used at the moment.
// Once app transitions to using console.error() for error logging,
//      use this function to get line number for console.log() instead of logging entire stacktrace.
var ua = navigator.userAgent.toLowerCase();
var extractLineNumberFromStack = function(stack) {
	if (!stack) return '?';
	// correct line number according to how Log().write implemented

	// iOS and desktop browser fix
	if ((window.platform === 'iOS' || ua.indexOf("android") <= -1) && typeof stack === 'string') {
		return stack.split('\n')[2];
	} else if (typeof stack === 'string') {
	    // since console-via-logger cordova plugin is being used, grab the 4th element in split array
	    var line = stack.split('\n')[3];
	}

	if (!line) {
		return 'no line info';
	}
	// fix for various display text
	line = (line.indexOf(' (') >= 0 ? line.split(' (')[1].substring(0, line.length - 1) : line.split('at ')[1]);
	//safari on mac
	if (!line) {
		var line = stack.split('\n')[2];
	}
	return line;
};
var log = console.log;
console.log = function() {
    if (arguments[0] && arguments[0].stack) {
        stack = arguments[0].stack;
    } else {
        stack = new Error().stack;
        if (!stack) {
            var stack = getStacktrace();
        }
    }
    //var lineInfo = extractLineNumberFromStack(stack);
    var args = Array.prototype.slice.call(arguments);
    if (typeof args[0] === 'string') {
        var first = args[0];
        if (args.length > 1) {
            args.shift();
            var dataToLog = {
                'arguments': args,
                'platform': (ua.indexOf("android") > -1) ? "Android" : window.platform,
                'stackTrace': stack
            };
            LE.log(first, dataToLog);
        } else {
            var dataToLog = {
                'platform': (ua.indexOf("android") > -1) ? "Android" : window.platform,
                'stackTrace': stack
            };
            LE.log(first, dataToLog);
        }
    } else {
        var dataToLog = {
            'arguments': args,
            'platform': (ua.indexOf("android") > -1) ? "Android" : window.platform,
            'stackTrace': stack
        };
        LE.log(dataToLog);
    }
    log.apply(this, arguments);
    console.debug('^-> ', stack);
};

var errorLog = console.error;
console.error = function() {
    if (arguments[0] && arguments[0].stack) {
        stack = arguments[0].stack;
    } else {
        stack = new Error().stack;
        if (!stack) {
            var stack = getStacktrace();
        }
    }
    //var lineInfo = extractLineNumberFromStack(stack);
    var args = Array.prototype.slice.call(arguments);
    if (typeof args[0] === 'string') {
        var first = args[0];
        if (args.length > 1) {
            args.shift();
            var dataToLog = {
                'arguments': args,
                'platform': (ua.indexOf("android") > -1) ? "Android" : window.platform,
                'stackTrace': stack
            };
            LE.error(first, dataToLog);
        } else {
            var dataToLog = {
                'platform': (ua.indexOf("android") > -1) ? "Android" : window.platform,
                'stackTrace': stack
            };
            LE.error(first, dataToLog);
        }
    } else {
        var dataToLog = {
            'arguments': args,
            'platform': (ua.indexOf("android") > -1) ? "Android" : window.platform,
            'stackTrace': stack
        };
        LE.error(dataToLog);
    }
    errorLog.apply(this, arguments);
};

// Mixpanel Analytics
(function(e,b){if(!b.__SV){var a,f,i,g;window.mixpanel=b;b._i=[];b.init=function(a,e,d){function f(b,h){var a=h.split(".");2==a.length&&(b=b[a[0]],h=a[1]);b[h]=function(){b.push([h].concat(Array.prototype.slice.call(arguments,0)))}}var c=b;"undefined"!==typeof d?c=b[d]=[]:d="mixpanel";c.people=c.people||[];c.toString=function(b){var a="mixpanel";"mixpanel"!==d&&(a+="."+d);b||(a+=" (stub)");return a};c.people.toString=function(){return c.toString(1)+".people (stub)"};i="disable time_event track track_pageview track_links track_forms register register_once alias unregister identify name_tag set_config people.set people.set_once people.increment people.append people.union people.track_charge people.clear_charges people.delete_user".split(" ");
for(g=0;g<i.length;g++)f(c,i[g]);b._i.push([a,e,d])};b.__SV=1.2;a=e.createElement("script");a.type="text/javascript";a.async=!0;a.src="undefined"!==typeof MIXPANEL_CUSTOM_LIB_URL?MIXPANEL_CUSTOM_LIB_URL:"file:"===e.location.protocol&&"//cdn.mxpnl.com/libs/mixpanel-2-latest.min.js".match(/^\/\//)?"https://cdn.mxpnl.com/libs/mixpanel-2-latest.min.js":"//cdn.mxpnl.com/libs/mixpanel-2-latest.min.js";f=e.getElementsByTagName("script")[0];f.parentNode.insertBefore(a,f)}})(document,window.mixpanel||[]);
mixpanel.init(analyticsMixPanelKey);

// Amplitude Analytics
(function(t,e){var n=t.amplitude||{};var r=e.createElement("script");r.type="text/javascript";
r.async=true;r.src="https://d24n15hnbwhuhn.cloudfront.net/libs/amplitude-2.5.0-min.gz.js";
r.onload=function(){t.amplitude.runQueuedFunctions()};var s=e.getElementsByTagName("script")[0];
s.parentNode.insertBefore(r,s);var i=function(){this._q=[];return this};function o(t){
i.prototype[t]=function(){this._q.push([t].concat(Array.prototype.slice.call(arguments,0)));
return this}}var a=["add","set","setOnce","unset"];for(var u=0;u<a.length;u++){o(a[u]);
}n.Identify=i;n._q=[];function c(t){n[t]=function(){n._q.push([t].concat(Array.prototype.slice.call(arguments,0)));
}}var l=["init","logEvent","logRevenue","setUserId","setUserProperties","setOptOut","setVersionName","setDomain","setDeviceId","setGlobalUserProperties","identify"];
for(var p=0;p<l.length;p++){c(l[p])}t.amplitude=n})(window,document);
amplitude.init(analyticsAmplitudeKey);
